@@ -3,5 +3,5 @@ from .items import Items, Details, Calendars
 from .logistics import Pickups, Dropoffs, Logistics
 from .orders import Orders, Extensions
 from .reservations import Reservations
-from .texts import Tags, Testimonials, Reviews
+from .texts import Tags, Testimonials, Reviews, Issues
 from .users import Users, Profiles, Carts
